# LRGASP Submissions

Documentation and software for submitting to the
Long Read Genome Annotation Assessment Project (LRGASP).

## Documentation

- [Challenges](docs/challenges.md)
- LRGASP data
  - [Reference genomes and transcripts](docs/reference-genomes.md)
  - [RNA-Seq data](docs/rnaseq-data-matrix.md)
- [Submission structure](docs/submission.md)
- Submission formats:
  - [Metadata](docs/metadata.md)
  - [Metadata identifiers](docs/metadata-identifiers.md)
  - [Transcript model format](docs/model-format.md)
  - [Read to model map format](docs/read_model_map_format.md)
  - [Transcript expression matrix format](docs/expression_matrix_format.md)
  - [Submission tools](docs/submission-tools.md)
  - [Synapse submissions](docs/synapse.md)

## Bug and feature requests

If there are questions or problems with this software, please create an issue in the
[LRGASP submissions GitHub tracker](https://github.com/LRGASP/lrgasp-submissions/issues).

## Contacts

- [lrgasp-support](mailto:lrgasp-support-group@ucsc.edu) Support list for LRGASP participants. Messages will not be shared publicly
- [lrgasp-announce](mailto:lrgasp-announce-group@ucsc.edu) Announcement list for the LRGASP.


